# __init__.py

"""
    repo_lifecycles is a small, lightweight data collection tool to support the longitudinal
    analysis of software repositories. 
"""

from .main import repo_lifecycle

__all__ = [
    "repo_lifecycle"
]
